# frozen_string_literal: true

module FlatironS3Uploader
  class FileUploader
    attr_reader :client

    def initialize(client)
      @client = client
    end

    def upload(bucket, image, mime_type, directory = nil)
      key = create_key(image, directory)
      client.put_object(bucket: bucket, key: key, acl: 'public-read', body: image, content_type: mime_type)
      "https://#{bucket}.s3.amazonaws.com/#{key}"
    end

    private

    def create_key(image, directory)
      filename = File.basename(image).sub('-resized', '')
      directory ? "#{directory}/#{filename}" : filename
    end
  end
end
