# frozen_string_literal: true

require 'mini_magick'

module FlatironS3Uploader
  class ImageResizer
    attr_reader :path, :image

    def initialize(path)
      raise FlatironS3Uploader::FileNotFoundError unless File.exist?(path)

      @path = path
      @image = MiniMagick::Image.open(path)
    end

    def resize(width: nil, height: nil)
      image.resize("#{width}x#{height}")
      image.write(output_path)
      output_path
    end

    def mime_type
      image.mime_type
    end

    private

    def output_path
      return @output_path if @output_path

      file_name = File.basename(path).sub('.', '-resized.')
      directory = File.dirname(path)
      @output_path = "#{directory}/#{file_name}"
    end
  end
end
